import * as cdk from '@aws-cdk/core';
/**
 * Schema for Module Fragment of type AWSQS::CheckPoint::CloudGuardQS::MODULE.
 *
 * @schema CfnCloudGuardQsModuleProps
 */
export interface CfnCloudGuardQsModuleProps {
    /**
     * @schema CfnCloudGuardQsModuleProps#Parameters
     */
    readonly parameters?: CfnCloudGuardQsModulePropsParameters;
    /**
     * @schema CfnCloudGuardQsModuleProps#Resources
     */
    readonly resources?: CfnCloudGuardQsModulePropsResources;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModuleProps' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModuleProps(obj: CfnCloudGuardQsModuleProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsParameters
 */
export interface CfnCloudGuardQsModulePropsParameters {
    /**
     * List of Availability Zones (AZs) to use for the subnets in the VPC.
     *
     * Select at least two
     *
     * @schema CfnCloudGuardQsModulePropsParameters#AvailabilityZones
     */
    readonly availabilityZones?: CfnCloudGuardQsModulePropsParametersAvailabilityZones;
    /**
     * Number of Availability Zones to use in the VPC.
     *
     * This must match your selections in the list of Availability Zones parameter.  Default: 2
     *
     * @schema CfnCloudGuardQsModulePropsParameters#NumberOfAZs
     */
    readonly numberOfAZs?: CfnCloudGuardQsModulePropsParametersNumberOfAZs;
    /**
     * CIDR block for the VPC.
     *
     * Default: 10.0.0.0/16
     *
     * @schema CfnCloudGuardQsModulePropsParameters#VPCCIDR
     */
    readonly vpccidr?: CfnCloudGuardQsModulePropsParametersVpccidr;
    /**
     * CIDR block for public subnet 1 located in the 1st Availability Zone.
     *
     * If you choose to deploy a Security Management Server it will be deployed in this subnet. Default: 10.0.10.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PublicSubnet1CIDR
     */
    readonly publicSubnet1Cidr?: CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr;
    /**
     * CIDR block for public subnet 2 located in the 2nd Availability Zone.
     *
     * Default: 10.0.20.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PublicSubnet2CIDR
     */
    readonly publicSubnet2Cidr?: CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr;
    /**
     * CIDR block for public subnet 3 located in the 3rd Availability Zone.
     *
     * Default: 10.0.30.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PublicSubnet3CIDR
     */
    readonly publicSubnet3Cidr?: CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr;
    /**
     * CIDR block for public subnet 4 located in the 4th Availability Zone.
     *
     * Default: 10.0.40.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PublicSubnet4CIDR
     */
    readonly publicSubnet4Cidr?: CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr;
    /**
     * CIDR block for private subnet 1 located in the 1st Availability Zone.
     *
     * Default: 10.0.11.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PrivateSubnet1CIDR
     */
    readonly privateSubnet1Cidr?: CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr;
    /**
     * CIDR block for private subnet 2 located in the 2nd Availability Zone.
     *
     * Default: 10.0.21.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PrivateSubnet2CIDR
     */
    readonly privateSubnet2Cidr?: CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr;
    /**
     * CIDR block for private subnet 3 located in the 3rd Availability Zone.
     *
     * Default: 10.0.31.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PrivateSubnet3CIDR
     */
    readonly privateSubnet3Cidr?: CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr;
    /**
     * CIDR block for private subnet 4 located in the 4th Availability Zone.
     *
     * Default: 10.0.41.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PrivateSubnet4CIDR
     */
    readonly privateSubnet4Cidr?: CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr;
    /**
     * The EC2 Key Pair to allow SSH access to the instances.
     *
     * For more detail visit: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html
     *
     * @schema CfnCloudGuardQsModulePropsParameters#KeyName
     */
    readonly keyName?: CfnCloudGuardQsModulePropsParametersKeyName;
    /**
     * Encrypt Environment instances volume with default AWS KMS key.
     *
     * Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#EnableVolumeEncryption
     */
    readonly enableVolumeEncryption?: CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption;
    /**
     * Enable SSH connection over AWS web console.
     *
     * Default: false
     *
     * @schema CfnCloudGuardQsModulePropsParameters#EnableInstanceConnect
     */
    readonly enableInstanceConnect?: CfnCloudGuardQsModulePropsParametersEnableInstanceConnect;
    /**
     * Automatically download Blade Contracts and other important data.
     *
     * Improve product experience by sending data to Check Point. Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#AllowUploadDownload
     */
    readonly allowUploadDownload?: CfnCloudGuardQsModulePropsParametersAllowUploadDownload;
    /**
     * The tag is used by the Security Management Server to automatically provision the Security Gateways.
     *
     * Must be up to 12 alphanumeric characters and unique for each Quick Start deployment. Default: quickstart
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ProvisionTag
     */
    readonly provisionTag?: CfnCloudGuardQsModulePropsParametersProvisionTag;
    /**
     * Use Network Load Balancer if you wish to preserve the source IP address and Application Load Balancer if you wish to perform SSL Offloading.
     *
     * Default: Network Load Balancer. Allowed values: Network Load Balancer, Application Load Balancer
     *
     * @schema CfnCloudGuardQsModulePropsParameters#LoadBalancersType
     */
    readonly loadBalancersType?: CfnCloudGuardQsModulePropsParametersLoadBalancersType;
    /**
     * The protocol to use on the Application Load Balancer.
     *
     * If Network Load Balancer was selected this section will be ignored. Default: HTTP. Allowed values: HTTP, HTTPS
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ALBProtocol
     */
    readonly albProtocol?: CfnCloudGuardQsModulePropsParametersAlbProtocol;
    /**
     * The protocol to use on the Network Load Balancer.
     *
     * If Application Load Balancer was selected this section will be ignored. Default: TCP. Allowed values: TCP, TLS, UDP, TCP_UDP
     *
     * @schema CfnCloudGuardQsModulePropsParameters#NLBProtocol
     */
    readonly nlbProtocol?: CfnCloudGuardQsModulePropsParametersNlbProtocol;
    /**
     * Amazon Resource Name (ARN) of an HTTPS Certificate, ignored if the selected protocol is HTTP (for the ALBProtocol parameter).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#Certificate
     */
    readonly certificate?: CfnCloudGuardQsModulePropsParametersCertificate;
    /**
     * The external Load Balancer listens to this port.
     *
     * Leave this field blank to use default ports: 80 for HTTP and 443 for HTTPS
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServicePort
     */
    readonly servicePort?: CfnCloudGuardQsModulePropsParametersServicePort;
    /**
     * Notifications about scaling events will be sent to this email address (optional).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#AdminEmail
     */
    readonly adminEmail?: CfnCloudGuardQsModulePropsParametersAdminEmail;
    /**
     * The EC2 instance type for the Security Gateways.
     *
     * Default: c5.xlarge. Allowed values: c5.xlarge, c5.xlarge, c5.2xlarge, c5.4xlarge, c5.9xlarge, c5.18xlarge, c5n.large, c5n.xlarge, c5n.2xlarge, c5n.4xlarge, c5n.9xlarge, c5n.18xlarge
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewayInstanceType
     */
    readonly gatewayInstanceType?: CfnCloudGuardQsModulePropsParametersGatewayInstanceType;
    /**
     * The minimal number of Security Gateways.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysMinSize
     */
    readonly gatewaysMinSize?: CfnCloudGuardQsModulePropsParametersGatewaysMinSize;
    /**
     * The maximal number of Security Gateways.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysMaxSize
     */
    readonly gatewaysMaxSize?: CfnCloudGuardQsModulePropsParametersGatewaysMaxSize;
    /**
     * The version and license to install on the Security Gateways.
     *
     * Default: R80.40-PAYG-NGTP-GW. Allowed values: R80.40-BYOL-GW, R80.40-PAYG-NGTP-GW, R80.40-PAYG-NGTX-GW, R81-BYOL-GW, R81-PAYG-NGTP-GW, R81-PAYG-NGTX-GW
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewayVersion
     */
    readonly gatewayVersion?: CfnCloudGuardQsModulePropsParametersGatewayVersion;
    /**
     * Admin user's password hash (use command "openssl passwd -1 PASSWORD" to get the PASSWORD's hash) (optional).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewayPasswordHash
     */
    readonly gatewayPasswordHash?: CfnCloudGuardQsModulePropsParametersGatewayPasswordHash;
    /**
     * The Secure Internal Communication key creates trusted connections between Check Point components.
     *
     * Choose a random string consisting of at least 8 alphanumeric characters.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaySICKey
     */
    readonly gatewaySicKey?: CfnCloudGuardQsModulePropsParametersGatewaySicKey;
    /**
     * Report Check Point specific CloudWatch metrics.
     *
     * Default: false
     *
     * @schema CfnCloudGuardQsModulePropsParameters#CloudWatch
     */
    readonly cloudWatch?: CfnCloudGuardQsModulePropsParametersCloudWatch;
    /**
     * Select false to use an existing Security Management Server or to deploy one later and to ignore the other parameters of this section.
     *
     * Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementDeploy
     */
    readonly managementDeploy?: CfnCloudGuardQsModulePropsParametersManagementDeploy;
    /**
     * The EC2 instance type of the Security Management Server.
     *
     * Default: m5.xlarge. Allowed values: m5.large, m5.xlarge, m5.2xlarge, m5.4xlarge, m5.12xlarge, m5.24xlarge
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementInstanceType
     */
    readonly managementInstanceType?: CfnCloudGuardQsModulePropsParametersManagementInstanceType;
    /**
     * The version and license to install on the Security Management Server.
     *
     * Default: R80.40-PAYG-MGMT. Allowed values: R80.40-BYOL-MGMT, R80.40-PAYG-MGMT, R81-BYOL-MGMT, R81-PAYG-MGMT
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementVersion
     */
    readonly managementVersion?: CfnCloudGuardQsModulePropsParametersManagementVersion;
    /**
     * Admin user's password hash (use command "openssl passwd -1 PASSWORD" to get the PASSWORD's hash) (optional).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementPasswordHash
     */
    readonly managementPasswordHash?: CfnCloudGuardQsModulePropsParametersManagementPasswordHash;
    /**
     * The name of the Security Policy package to be installed on the gateways in the Security Gateways Auto Scaling group.
     *
     * Default: Standard
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysPolicy
     */
    readonly gatewaysPolicy?: CfnCloudGuardQsModulePropsParametersGatewaysPolicy;
    /**
     * Turn on the Intrusion Prevention System, Application Control, Anti-Virus and Anti-Bot Blades (these and additional Blades can be manually turned on or off later).
     *
     * Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysBlades
     */
    readonly gatewaysBlades?: CfnCloudGuardQsModulePropsParametersGatewaysBlades;
    /**
     * Allow web, SSH, and graphical clients only from this network to communicate with the Security Management Server.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#AdminCIDR
     */
    readonly adminCidr?: CfnCloudGuardQsModulePropsParametersAdminCidr;
    /**
     * Allow gateways only from this network to communicate with the Security Management Server.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysAddresses
     */
    readonly gatewaysAddresses?: CfnCloudGuardQsModulePropsParametersGatewaysAddresses;
    /**
     * Select true to deploy web servers and an internal Application Load Balancer.
     *
     * If you select false the other parameters of this section will be ignored. Default: false
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServersDeploy
     */
    readonly serversDeploy?: CfnCloudGuardQsModulePropsParametersServersDeploy;
    /**
     * The EC2 instance type for the web servers.
     *
     * Default: t3.micro. Allowed values: t3.nano, t3.micro, t3.small, t3.medium, t3.large, t3.xlarge, t3.2xlarge
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServerInstanceType
     */
    readonly serverInstanceType?: CfnCloudGuardQsModulePropsParametersServerInstanceType;
    /**
     * The Amazon Machine Image ID of a preconfigured web server (e.g. ami-0dc7dc63).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServerAMI
     */
    readonly serverAmi?: CfnCloudGuardQsModulePropsParametersServerAmi;
    /**
     * Set to false to create only public subnets.
     *
     * If false, the CIDR parameters for ALL private subnets will be ignored. Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#CreatePrivateSubnets
     */
    readonly createPrivateSubnets?: CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets;
    /**
     * Set true for creating designated subnets for VPC TGW attachments.
     *
     * If false, the CIDR parameters for the TGW subnets will be ignored. Default: false
     *
     * @schema CfnCloudGuardQsModulePropsParameters#CreateTgwSubnets
     */
    readonly createTgwSubnets?: CfnCloudGuardQsModulePropsParametersCreateTgwSubnets;
    /**
     * CIDR block for TGW subnet 1 located in Availability Zone 1.
     *
     * Default: 10.0.12.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#TgwSubnet1CIDR
     */
    readonly tgwSubnet1Cidr?: CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr;
    /**
     * CIDR block for TGW subnet 2 located in Availability Zone 2.
     *
     * Default: 10.0.22.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#TgwSubnet2CIDR
     */
    readonly tgwSubnet2Cidr?: CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr;
    /**
     * CIDR block for TGW subnet 3 located in Availability Zone 3.
     *
     * Default: 10.0.32.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#TgwSubnet3CIDR
     */
    readonly tgwSubnet3Cidr?: CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr;
    /**
     * CIDR block for TGW subnet 4 located in Availability Zone 4.
     *
     * Default: 10.0.42.0/24
     *
     * @schema CfnCloudGuardQsModulePropsParameters#TgwSubnet4CIDR
     */
    readonly tgwSubnet4Cidr?: CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr;
    /**
     * Port for the ELB.
     *
     * Default: 8080
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ELBPort
     */
    readonly elbPort?: CfnCloudGuardQsModulePropsParametersElbPort;
    /**
     * Allocate an elastic IP for the Management.
     *
     * Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#AllocatePublicAddress
     */
    readonly allocatePublicAddress?: CfnCloudGuardQsModulePropsParametersAllocatePublicAddress;
    /**
     * IAM role to attach to the instance profile of the Management Server.
     *
     * Default: Create with read permissions. Allowed values: None (configure later), Use existing (specify an existing IAM role name), Create with assume role permissions (specify an STS role ARN), Create with read permissions, Create with read-write permissions
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementPermissions
     */
    readonly managementPermissions?: CfnCloudGuardQsModulePropsParametersManagementPermissions;
    /**
     * Select 'Over the internet' if any of the gateways you wish to manage are not directly accessed via their private IP address.
     *
     * Default: 'Locally managed'. Allowed values: Locally managed, Over the internet
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewayManagement
     */
    readonly gatewayManagement?: CfnCloudGuardQsModulePropsParametersGatewayManagement;
    /**
     * Mandatory only if deploying a secondary Management Server, the Secure Internal Communication key creates trusted connections between Check Point components.
     *
     * Choose a random string consisting of at least 8 alphanumeric characters
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementSICKey
     */
    readonly managementSicKey?: CfnCloudGuardQsModulePropsParametersManagementSicKey;
    /**
     * A predefined IAM role to attach to the instance profile.
     *
     * Ignored if IAM role is not set to 'Use existing'
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementPredefinedRole
     */
    readonly managementPredefinedRole?: CfnCloudGuardQsModulePropsParametersManagementPredefinedRole;
    /**
     * (optional).
     *
     * Default: 169.254.169.123
     *
     * @schema CfnCloudGuardQsModulePropsParameters#NTPPrimary
     */
    readonly ntpPrimary?: CfnCloudGuardQsModulePropsParametersNtpPrimary;
    /**
     * (optional).
     *
     * Default: 0.pool.ntp.org
     *
     * @schema CfnCloudGuardQsModulePropsParameters#NTPSecondary
     */
    readonly ntpSecondary?: CfnCloudGuardQsModulePropsParametersNtpSecondary;
    /**
     * (optional).
     *
     * Default: mgmt-aws
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementHostname
     */
    readonly managementHostname?: CfnCloudGuardQsModulePropsParametersManagementHostname;
    /**
     * Determines if this is the primary Management Server or not.
     *
     * Default: true
     *
     * @schema CfnCloudGuardQsModulePropsParameters#PrimaryManagement
     */
    readonly primaryManagement?: CfnCloudGuardQsModulePropsParametersPrimaryManagement;
    /**
     * EBS Volume size of the management server.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ManagementStackVolumeSize
     */
    readonly managementStackVolumeSize?: CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize;
    /**
     * Change the admin shell to enable advanced command line configuration.
     *
     * Default: /etc/cli.sh. Allowed values: /etc/cli.sh, /bin/bash, /bin/csh, /bin/tcsh
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ShellManagementStack
     */
    readonly shellManagementStack?: CfnCloudGuardQsModulePropsParametersShellManagementStack;
    /**
     * The Elasitc Load Balancer Type.
     *
     * Default: none. Allowed values: none, internal, internet-facing
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ELBType
     */
    readonly elbType?: CfnCloudGuardQsModulePropsParametersElbType;
    /**
     * A list of Target Groups to associate with the Auto Scaling group (comma separated list of ARNs, without spaces) (optional).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#GatewaysTargetGroups
     */
    readonly gatewaysTargetGroups?: CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups;
    /**
     * Determines if the gateways are provisioned using their private or public address.
     *
     * Default: private. Allowed values: private, public
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ControlGatewayOverPrivateOrPublicAddress
     */
    readonly controlGatewayOverPrivateOrPublicAddress?: CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress;
    /**
     * EBS Volume size of the security gateway server.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#SecurityGatewayVolumeSize
     */
    readonly securityGatewayVolumeSize?: CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize;
    /**
     * Allow clients only from this network to communicate with the Web Servers.
     *
     * Default: 0.0.0.0/0
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ELBClients
     */
    readonly elbClients?: CfnCloudGuardQsModulePropsParametersElbClients;
    /**
     * Change the admin shell to enable advanced command line configuration.
     *
     * Default: /etc/cli.sh. Allowed Values: /etc/cli.sh /bin/bash /bin/csh /bin/tcsh
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ShellSecurityGatewayStack
     */
    readonly shellSecurityGatewayStack?: CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack;
    /**
     * IAM Permissions for the management server.
     *
     * Default: Create with read permissions. Allowed values: Create with read permissions Create with read-write permissions Create with assume role permissions (specify an STS role ARN)
     *
     * @schema CfnCloudGuardQsModulePropsParameters#Permissions
     */
    readonly permissions?: CfnCloudGuardQsModulePropsParametersPermissions;
    /**
     * The IAM role will be able to assume these STS Roles (comma separated list of ARNs, without spaces).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#STSRoles
     */
    readonly stsRoles?: CfnCloudGuardQsModulePropsParametersStsRoles;
    /**
     * A 12 digits number that represents the ID of a trusted account.
     *
     * IAM users in this account will be able assume the IAM role and receive the permissions attached to it.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#TrustedAccount
     */
    readonly trustedAccount?: CfnCloudGuardQsModulePropsParametersTrustedAccount;
    /**
     * An optional list of Target Groups to associate with the Auto Scaling group (comma separated list of ARNs, without spaces).
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServersTargetGroups
     */
    readonly serversTargetGroups?: CfnCloudGuardQsModulePropsParametersServersTargetGroups;
    /**
     * The ID of Security Group from which access will be allowed to the instances in this Auto Scaling group.
     *
     * @schema CfnCloudGuardQsModulePropsParameters#SourceSecurityGroup
     */
    readonly sourceSecurityGroup?: CfnCloudGuardQsModulePropsParametersSourceSecurityGroup;
    /**
     * The minimal number of servers in the Auto Scaling group.
     *
     * Default: 2
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServersMinSize
     */
    readonly serversMinSize?: CfnCloudGuardQsModulePropsParametersServersMinSize;
    /**
     * The maximal number of servers in the Auto Scaling group.
     *
     * Default: 10
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServersMaxSize
     */
    readonly serversMaxSize?: CfnCloudGuardQsModulePropsParametersServersMaxSize;
    /**
     * The servers name tag.
     *
     * Default: Server
     *
     * @schema CfnCloudGuardQsModulePropsParameters#ServerName
     */
    readonly serverName?: CfnCloudGuardQsModulePropsParametersServerName;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParameters' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParameters(obj: CfnCloudGuardQsModulePropsParameters | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResources
 */
export interface CfnCloudGuardQsModulePropsResources {
    /**
     * @schema CfnCloudGuardQsModulePropsResources#VPC
     */
    readonly vpc?: CfnCloudGuardQsModulePropsResourcesVpc;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InternetGateway
     */
    readonly internetGateway?: CfnCloudGuardQsModulePropsResourcesInternetGateway;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#VPCGatewayAttachment
     */
    readonly vpcGatewayAttachment?: CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet1
     */
    readonly publicSubnet1?: CfnCloudGuardQsModulePropsResourcesPublicSubnet1;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet2
     */
    readonly publicSubnet2?: CfnCloudGuardQsModulePropsResourcesPublicSubnet2;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet3
     */
    readonly publicSubnet3?: CfnCloudGuardQsModulePropsResourcesPublicSubnet3;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet4
     */
    readonly publicSubnet4?: CfnCloudGuardQsModulePropsResourcesPublicSubnet4;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnetRouteTable
     */
    readonly publicSubnetRouteTable?: CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnetRoute
     */
    readonly publicSubnetRoute?: CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet1RouteTableAssociation
     */
    readonly publicSubnet1RouteTableAssociation?: CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet2RouteTableAssociation
     */
    readonly publicSubnet2RouteTableAssociation?: CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet3RouteTableAssociation
     */
    readonly publicSubnet3RouteTableAssociation?: CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicSubnet4RouteTableAssociation
     */
    readonly publicSubnet4RouteTableAssociation?: CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PrivateSubnet1
     */
    readonly privateSubnet1?: CfnCloudGuardQsModulePropsResourcesPrivateSubnet1;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PrivateSubnet2
     */
    readonly privateSubnet2?: CfnCloudGuardQsModulePropsResourcesPrivateSubnet2;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PrivateSubnet3
     */
    readonly privateSubnet3?: CfnCloudGuardQsModulePropsResourcesPrivateSubnet3;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PrivateSubnet4
     */
    readonly privateSubnet4?: CfnCloudGuardQsModulePropsResourcesPrivateSubnet4;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#TgwSubnet1
     */
    readonly tgwSubnet1?: CfnCloudGuardQsModulePropsResourcesTgwSubnet1;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#TgwSubnet2
     */
    readonly tgwSubnet2?: CfnCloudGuardQsModulePropsResourcesTgwSubnet2;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#TgwSubnet3
     */
    readonly tgwSubnet3?: CfnCloudGuardQsModulePropsResourcesTgwSubnet3;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#TgwSubnet4
     */
    readonly tgwSubnet4?: CfnCloudGuardQsModulePropsResourcesTgwSubnet4;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ExternalALBSecurityGroup
     */
    readonly externalAlbSecurityGroup?: CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ExternalLoadBalancer
     */
    readonly externalLoadBalancer?: CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ExternalLBTargetGroup
     */
    readonly externalLbTargetGroup?: CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ExternalLBListener
     */
    readonly externalLbListener?: CfnCloudGuardQsModulePropsResourcesExternalLbListener;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ChkpGatewayRole
     */
    readonly chkpGatewayRole?: CfnCloudGuardQsModulePropsResourcesChkpGatewayRole;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InstanceProfileSecurityGatewayStack
     */
    readonly instanceProfileSecurityGatewayStack?: CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#NotificationTopicSecurityGatewayStack
     */
    readonly notificationTopicSecurityGatewayStack?: CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ElasticLoadBalancer
     */
    readonly elasticLoadBalancer?: CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PermissiveSecurityGroup
     */
    readonly permissiveSecurityGroup?: CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#GatewayGroup
     */
    readonly gatewayGroup?: CfnCloudGuardQsModulePropsResourcesGatewayGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#GatewayLaunchConfig
     */
    readonly gatewayLaunchConfig?: CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#GatewayScaleUpPolicy
     */
    readonly gatewayScaleUpPolicy?: CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#GatewayScaleDownPolicy
     */
    readonly gatewayScaleDownPolicy?: CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#CPUAlarmHighSecurityGatewayStack
     */
    readonly cpuAlarmHighSecurityGatewayStack?: CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#CPUAlarmLowSecurityGatewayStack
     */
    readonly cpuAlarmLowSecurityGatewayStack?: CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ELBSecurityGroup
     */
    readonly elbSecurityGroup?: CfnCloudGuardQsModulePropsResourcesElbSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ManagementReadyHandle
     */
    readonly managementReadyHandle?: CfnCloudGuardQsModulePropsResourcesManagementReadyHandle;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ManagementReadyCondition
     */
    readonly managementReadyCondition?: CfnCloudGuardQsModulePropsResourcesManagementReadyCondition;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ManagementSecurityGroup
     */
    readonly managementSecurityGroup?: CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#CMEIAMRole
     */
    readonly cmeiamRole?: CfnCloudGuardQsModulePropsResourcesCmeiamRole;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InstanceProfile
     */
    readonly instanceProfile?: CfnCloudGuardQsModulePropsResourcesInstanceProfile;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ManagementInstance
     */
    readonly managementInstance?: CfnCloudGuardQsModulePropsResourcesManagementInstance;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#PublicAddress
     */
    readonly publicAddress?: CfnCloudGuardQsModulePropsResourcesPublicAddress;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#AddressAssoc
     */
    readonly addressAssoc?: CfnCloudGuardQsModulePropsResourcesAddressAssoc;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InternalSecurityGroup
     */
    readonly internalSecurityGroup?: CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InternalLBTargetGroup
     */
    readonly internalLbTargetGroup?: CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InternalLoadBalancer
     */
    readonly internalLoadBalancer?: CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#InternalLBListener
     */
    readonly internalLbListener?: CfnCloudGuardQsModulePropsResourcesInternalLbListener;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#NotificationTopic
     */
    readonly notificationTopic?: CfnCloudGuardQsModulePropsResourcesNotificationTopic;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ServersSecurityGroup
     */
    readonly serversSecurityGroup?: CfnCloudGuardQsModulePropsResourcesServersSecurityGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ServersLaunchConfiguration
     */
    readonly serversLaunchConfiguration?: CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ServersGroup
     */
    readonly serversGroup?: CfnCloudGuardQsModulePropsResourcesServersGroup;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ScaleUpPolicy
     */
    readonly scaleUpPolicy?: CfnCloudGuardQsModulePropsResourcesScaleUpPolicy;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#ScaleDownPolicy
     */
    readonly scaleDownPolicy?: CfnCloudGuardQsModulePropsResourcesScaleDownPolicy;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#CPUAlarmHigh
     */
    readonly cpuAlarmHigh?: CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh;
    /**
     * @schema CfnCloudGuardQsModulePropsResources#CPUAlarmLow
     */
    readonly cpuAlarmLow?: CfnCloudGuardQsModulePropsResourcesCpuAlarmLow;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResources' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResources(obj: CfnCloudGuardQsModulePropsResources | undefined): Record<string, any> | undefined;
/**
 * List of Availability Zones (AZs) to use for the subnets in the VPC.
 *
 * Select at least two
 *
 * @schema CfnCloudGuardQsModulePropsParametersAvailabilityZones
 */
export interface CfnCloudGuardQsModulePropsParametersAvailabilityZones {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAvailabilityZones#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAvailabilityZones#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAvailabilityZones' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAvailabilityZones(obj: CfnCloudGuardQsModulePropsParametersAvailabilityZones | undefined): Record<string, any> | undefined;
/**
 * Number of Availability Zones to use in the VPC.
 *
 * This must match your selections in the list of Availability Zones parameter.  Default: 2
 *
 * @schema CfnCloudGuardQsModulePropsParametersNumberOfAZs
 */
export interface CfnCloudGuardQsModulePropsParametersNumberOfAZs {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNumberOfAZs#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNumberOfAZs#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersNumberOfAZs' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersNumberOfAZs(obj: CfnCloudGuardQsModulePropsParametersNumberOfAZs | undefined): Record<string, any> | undefined;
/**
 * CIDR block for the VPC.
 *
 * Default: 10.0.0.0/16
 *
 * @schema CfnCloudGuardQsModulePropsParametersVpccidr
 */
export interface CfnCloudGuardQsModulePropsParametersVpccidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersVpccidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersVpccidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersVpccidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersVpccidr(obj: CfnCloudGuardQsModulePropsParametersVpccidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for public subnet 1 located in the 1st Availability Zone.
 *
 * If you choose to deploy a Security Management Server it will be deployed in this subnet. Default: 10.0.10.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr(obj: CfnCloudGuardQsModulePropsParametersPublicSubnet1Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for public subnet 2 located in the 2nd Availability Zone.
 *
 * Default: 10.0.20.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr(obj: CfnCloudGuardQsModulePropsParametersPublicSubnet2Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for public subnet 3 located in the 3rd Availability Zone.
 *
 * Default: 10.0.30.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr(obj: CfnCloudGuardQsModulePropsParametersPublicSubnet3Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for public subnet 4 located in the 4th Availability Zone.
 *
 * Default: 10.0.40.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr(obj: CfnCloudGuardQsModulePropsParametersPublicSubnet4Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for private subnet 1 located in the 1st Availability Zone.
 *
 * Default: 10.0.11.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr(obj: CfnCloudGuardQsModulePropsParametersPrivateSubnet1Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for private subnet 2 located in the 2nd Availability Zone.
 *
 * Default: 10.0.21.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr(obj: CfnCloudGuardQsModulePropsParametersPrivateSubnet2Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for private subnet 3 located in the 3rd Availability Zone.
 *
 * Default: 10.0.31.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr(obj: CfnCloudGuardQsModulePropsParametersPrivateSubnet3Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for private subnet 4 located in the 4th Availability Zone.
 *
 * Default: 10.0.41.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr(obj: CfnCloudGuardQsModulePropsParametersPrivateSubnet4Cidr | undefined): Record<string, any> | undefined;
/**
 * The EC2 Key Pair to allow SSH access to the instances.
 *
 * For more detail visit: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html
 *
 * @schema CfnCloudGuardQsModulePropsParametersKeyName
 */
export interface CfnCloudGuardQsModulePropsParametersKeyName {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersKeyName#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersKeyName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersKeyName' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersKeyName(obj: CfnCloudGuardQsModulePropsParametersKeyName | undefined): Record<string, any> | undefined;
/**
 * Encrypt Environment instances volume with default AWS KMS key.
 *
 * Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption
 */
export interface CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption(obj: CfnCloudGuardQsModulePropsParametersEnableVolumeEncryption | undefined): Record<string, any> | undefined;
/**
 * Enable SSH connection over AWS web console.
 *
 * Default: false
 *
 * @schema CfnCloudGuardQsModulePropsParametersEnableInstanceConnect
 */
export interface CfnCloudGuardQsModulePropsParametersEnableInstanceConnect {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersEnableInstanceConnect#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersEnableInstanceConnect#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersEnableInstanceConnect' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersEnableInstanceConnect(obj: CfnCloudGuardQsModulePropsParametersEnableInstanceConnect | undefined): Record<string, any> | undefined;
/**
 * Automatically download Blade Contracts and other important data.
 *
 * Improve product experience by sending data to Check Point. Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersAllowUploadDownload
 */
export interface CfnCloudGuardQsModulePropsParametersAllowUploadDownload {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAllowUploadDownload#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAllowUploadDownload#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAllowUploadDownload' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAllowUploadDownload(obj: CfnCloudGuardQsModulePropsParametersAllowUploadDownload | undefined): Record<string, any> | undefined;
/**
 * The tag is used by the Security Management Server to automatically provision the Security Gateways.
 *
 * Must be up to 12 alphanumeric characters and unique for each Quick Start deployment. Default: quickstart
 *
 * @schema CfnCloudGuardQsModulePropsParametersProvisionTag
 */
export interface CfnCloudGuardQsModulePropsParametersProvisionTag {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersProvisionTag#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersProvisionTag#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersProvisionTag' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersProvisionTag(obj: CfnCloudGuardQsModulePropsParametersProvisionTag | undefined): Record<string, any> | undefined;
/**
 * Use Network Load Balancer if you wish to preserve the source IP address and Application Load Balancer if you wish to perform SSL Offloading.
 *
 * Default: Network Load Balancer. Allowed values: Network Load Balancer, Application Load Balancer
 *
 * @schema CfnCloudGuardQsModulePropsParametersLoadBalancersType
 */
export interface CfnCloudGuardQsModulePropsParametersLoadBalancersType {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersLoadBalancersType#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersLoadBalancersType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersLoadBalancersType' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersLoadBalancersType(obj: CfnCloudGuardQsModulePropsParametersLoadBalancersType | undefined): Record<string, any> | undefined;
/**
 * The protocol to use on the Application Load Balancer.
 *
 * If Network Load Balancer was selected this section will be ignored. Default: HTTP. Allowed values: HTTP, HTTPS
 *
 * @schema CfnCloudGuardQsModulePropsParametersAlbProtocol
 */
export interface CfnCloudGuardQsModulePropsParametersAlbProtocol {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAlbProtocol#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAlbProtocol#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAlbProtocol' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAlbProtocol(obj: CfnCloudGuardQsModulePropsParametersAlbProtocol | undefined): Record<string, any> | undefined;
/**
 * The protocol to use on the Network Load Balancer.
 *
 * If Application Load Balancer was selected this section will be ignored. Default: TCP. Allowed values: TCP, TLS, UDP, TCP_UDP
 *
 * @schema CfnCloudGuardQsModulePropsParametersNlbProtocol
 */
export interface CfnCloudGuardQsModulePropsParametersNlbProtocol {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNlbProtocol#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNlbProtocol#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersNlbProtocol' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersNlbProtocol(obj: CfnCloudGuardQsModulePropsParametersNlbProtocol | undefined): Record<string, any> | undefined;
/**
 * Amazon Resource Name (ARN) of an HTTPS Certificate, ignored if the selected protocol is HTTP (for the ALBProtocol parameter).
 *
 * @schema CfnCloudGuardQsModulePropsParametersCertificate
 */
export interface CfnCloudGuardQsModulePropsParametersCertificate {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCertificate#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCertificate#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersCertificate' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersCertificate(obj: CfnCloudGuardQsModulePropsParametersCertificate | undefined): Record<string, any> | undefined;
/**
 * The external Load Balancer listens to this port.
 *
 * Leave this field blank to use default ports: 80 for HTTP and 443 for HTTPS
 *
 * @schema CfnCloudGuardQsModulePropsParametersServicePort
 */
export interface CfnCloudGuardQsModulePropsParametersServicePort {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServicePort#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServicePort#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServicePort' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServicePort(obj: CfnCloudGuardQsModulePropsParametersServicePort | undefined): Record<string, any> | undefined;
/**
 * Notifications about scaling events will be sent to this email address (optional).
 *
 * @schema CfnCloudGuardQsModulePropsParametersAdminEmail
 */
export interface CfnCloudGuardQsModulePropsParametersAdminEmail {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAdminEmail#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAdminEmail#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAdminEmail' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAdminEmail(obj: CfnCloudGuardQsModulePropsParametersAdminEmail | undefined): Record<string, any> | undefined;
/**
 * The EC2 instance type for the Security Gateways.
 *
 * Default: c5.xlarge. Allowed values: c5.xlarge, c5.xlarge, c5.2xlarge, c5.4xlarge, c5.9xlarge, c5.18xlarge, c5n.large, c5n.xlarge, c5n.2xlarge, c5n.4xlarge, c5n.9xlarge, c5n.18xlarge
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewayInstanceType
 */
export interface CfnCloudGuardQsModulePropsParametersGatewayInstanceType {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewayInstanceType' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewayInstanceType(obj: CfnCloudGuardQsModulePropsParametersGatewayInstanceType | undefined): Record<string, any> | undefined;
/**
 * The minimal number of Security Gateways.
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysMinSize
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysMinSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysMinSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysMinSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysMinSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysMinSize(obj: CfnCloudGuardQsModulePropsParametersGatewaysMinSize | undefined): Record<string, any> | undefined;
/**
 * The maximal number of Security Gateways.
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysMaxSize
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysMaxSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysMaxSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysMaxSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysMaxSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysMaxSize(obj: CfnCloudGuardQsModulePropsParametersGatewaysMaxSize | undefined): Record<string, any> | undefined;
/**
 * The version and license to install on the Security Gateways.
 *
 * Default: R80.40-PAYG-NGTP-GW. Allowed values: R80.40-BYOL-GW, R80.40-PAYG-NGTP-GW, R80.40-PAYG-NGTX-GW, R81-BYOL-GW, R81-PAYG-NGTP-GW, R81-PAYG-NGTX-GW
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewayVersion
 */
export interface CfnCloudGuardQsModulePropsParametersGatewayVersion {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayVersion#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayVersion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewayVersion' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewayVersion(obj: CfnCloudGuardQsModulePropsParametersGatewayVersion | undefined): Record<string, any> | undefined;
/**
 * Admin user's password hash (use command "openssl passwd -1 PASSWORD" to get the PASSWORD's hash) (optional).
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewayPasswordHash
 */
export interface CfnCloudGuardQsModulePropsParametersGatewayPasswordHash {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayPasswordHash#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayPasswordHash#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewayPasswordHash' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewayPasswordHash(obj: CfnCloudGuardQsModulePropsParametersGatewayPasswordHash | undefined): Record<string, any> | undefined;
/**
 * The Secure Internal Communication key creates trusted connections between Check Point components.
 *
 * Choose a random string consisting of at least 8 alphanumeric characters.
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaySicKey
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaySicKey {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaySicKey#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaySicKey#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaySicKey' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaySicKey(obj: CfnCloudGuardQsModulePropsParametersGatewaySicKey | undefined): Record<string, any> | undefined;
/**
 * Report Check Point specific CloudWatch metrics.
 *
 * Default: false
 *
 * @schema CfnCloudGuardQsModulePropsParametersCloudWatch
 */
export interface CfnCloudGuardQsModulePropsParametersCloudWatch {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCloudWatch#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCloudWatch#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersCloudWatch' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersCloudWatch(obj: CfnCloudGuardQsModulePropsParametersCloudWatch | undefined): Record<string, any> | undefined;
/**
 * Select false to use an existing Security Management Server or to deploy one later and to ignore the other parameters of this section.
 *
 * Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementDeploy
 */
export interface CfnCloudGuardQsModulePropsParametersManagementDeploy {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementDeploy#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementDeploy#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementDeploy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementDeploy(obj: CfnCloudGuardQsModulePropsParametersManagementDeploy | undefined): Record<string, any> | undefined;
/**
 * The EC2 instance type of the Security Management Server.
 *
 * Default: m5.xlarge. Allowed values: m5.large, m5.xlarge, m5.2xlarge, m5.4xlarge, m5.12xlarge, m5.24xlarge
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementInstanceType
 */
export interface CfnCloudGuardQsModulePropsParametersManagementInstanceType {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementInstanceType' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementInstanceType(obj: CfnCloudGuardQsModulePropsParametersManagementInstanceType | undefined): Record<string, any> | undefined;
/**
 * The version and license to install on the Security Management Server.
 *
 * Default: R80.40-PAYG-MGMT. Allowed values: R80.40-BYOL-MGMT, R80.40-PAYG-MGMT, R81-BYOL-MGMT, R81-PAYG-MGMT
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementVersion
 */
export interface CfnCloudGuardQsModulePropsParametersManagementVersion {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementVersion#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementVersion#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementVersion' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementVersion(obj: CfnCloudGuardQsModulePropsParametersManagementVersion | undefined): Record<string, any> | undefined;
/**
 * Admin user's password hash (use command "openssl passwd -1 PASSWORD" to get the PASSWORD's hash) (optional).
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementPasswordHash
 */
export interface CfnCloudGuardQsModulePropsParametersManagementPasswordHash {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPasswordHash#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPasswordHash#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementPasswordHash' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementPasswordHash(obj: CfnCloudGuardQsModulePropsParametersManagementPasswordHash | undefined): Record<string, any> | undefined;
/**
 * The name of the Security Policy package to be installed on the gateways in the Security Gateways Auto Scaling group.
 *
 * Default: Standard
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysPolicy
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysPolicy {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysPolicy#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysPolicy#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysPolicy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysPolicy(obj: CfnCloudGuardQsModulePropsParametersGatewaysPolicy | undefined): Record<string, any> | undefined;
/**
 * Turn on the Intrusion Prevention System, Application Control, Anti-Virus and Anti-Bot Blades (these and additional Blades can be manually turned on or off later).
 *
 * Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysBlades
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysBlades {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysBlades#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysBlades#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysBlades' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysBlades(obj: CfnCloudGuardQsModulePropsParametersGatewaysBlades | undefined): Record<string, any> | undefined;
/**
 * Allow web, SSH, and graphical clients only from this network to communicate with the Security Management Server.
 *
 * @schema CfnCloudGuardQsModulePropsParametersAdminCidr
 */
export interface CfnCloudGuardQsModulePropsParametersAdminCidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAdminCidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAdminCidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAdminCidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAdminCidr(obj: CfnCloudGuardQsModulePropsParametersAdminCidr | undefined): Record<string, any> | undefined;
/**
 * Allow gateways only from this network to communicate with the Security Management Server.
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysAddresses
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysAddresses {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysAddresses#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysAddresses#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysAddresses' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysAddresses(obj: CfnCloudGuardQsModulePropsParametersGatewaysAddresses | undefined): Record<string, any> | undefined;
/**
 * Select true to deploy web servers and an internal Application Load Balancer.
 *
 * If you select false the other parameters of this section will be ignored. Default: false
 *
 * @schema CfnCloudGuardQsModulePropsParametersServersDeploy
 */
export interface CfnCloudGuardQsModulePropsParametersServersDeploy {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersDeploy#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersDeploy#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServersDeploy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServersDeploy(obj: CfnCloudGuardQsModulePropsParametersServersDeploy | undefined): Record<string, any> | undefined;
/**
 * The EC2 instance type for the web servers.
 *
 * Default: t3.micro. Allowed values: t3.nano, t3.micro, t3.small, t3.medium, t3.large, t3.xlarge, t3.2xlarge
 *
 * @schema CfnCloudGuardQsModulePropsParametersServerInstanceType
 */
export interface CfnCloudGuardQsModulePropsParametersServerInstanceType {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerInstanceType#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerInstanceType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServerInstanceType' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServerInstanceType(obj: CfnCloudGuardQsModulePropsParametersServerInstanceType | undefined): Record<string, any> | undefined;
/**
 * The Amazon Machine Image ID of a preconfigured web server (e.g. ami-0dc7dc63).
 *
 * @schema CfnCloudGuardQsModulePropsParametersServerAmi
 */
export interface CfnCloudGuardQsModulePropsParametersServerAmi {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerAmi#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerAmi#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServerAmi' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServerAmi(obj: CfnCloudGuardQsModulePropsParametersServerAmi | undefined): Record<string, any> | undefined;
/**
 * Set to false to create only public subnets.
 *
 * If false, the CIDR parameters for ALL private subnets will be ignored. Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets
 */
export interface CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets(obj: CfnCloudGuardQsModulePropsParametersCreatePrivateSubnets | undefined): Record<string, any> | undefined;
/**
 * Set true for creating designated subnets for VPC TGW attachments.
 *
 * If false, the CIDR parameters for the TGW subnets will be ignored. Default: false
 *
 * @schema CfnCloudGuardQsModulePropsParametersCreateTgwSubnets
 */
export interface CfnCloudGuardQsModulePropsParametersCreateTgwSubnets {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCreateTgwSubnets#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersCreateTgwSubnets#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersCreateTgwSubnets' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersCreateTgwSubnets(obj: CfnCloudGuardQsModulePropsParametersCreateTgwSubnets | undefined): Record<string, any> | undefined;
/**
 * CIDR block for TGW subnet 1 located in Availability Zone 1.
 *
 * Default: 10.0.12.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr(obj: CfnCloudGuardQsModulePropsParametersTgwSubnet1Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for TGW subnet 2 located in Availability Zone 2.
 *
 * Default: 10.0.22.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr(obj: CfnCloudGuardQsModulePropsParametersTgwSubnet2Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for TGW subnet 3 located in Availability Zone 3.
 *
 * Default: 10.0.32.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr(obj: CfnCloudGuardQsModulePropsParametersTgwSubnet3Cidr | undefined): Record<string, any> | undefined;
/**
 * CIDR block for TGW subnet 4 located in Availability Zone 4.
 *
 * Default: 10.0.42.0/24
 *
 * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr
 */
export interface CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr(obj: CfnCloudGuardQsModulePropsParametersTgwSubnet4Cidr | undefined): Record<string, any> | undefined;
/**
 * Port for the ELB.
 *
 * Default: 8080
 *
 * @schema CfnCloudGuardQsModulePropsParametersElbPort
 */
export interface CfnCloudGuardQsModulePropsParametersElbPort {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbPort#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbPort#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersElbPort' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersElbPort(obj: CfnCloudGuardQsModulePropsParametersElbPort | undefined): Record<string, any> | undefined;
/**
 * Allocate an elastic IP for the Management.
 *
 * Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersAllocatePublicAddress
 */
export interface CfnCloudGuardQsModulePropsParametersAllocatePublicAddress {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAllocatePublicAddress#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersAllocatePublicAddress#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersAllocatePublicAddress' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersAllocatePublicAddress(obj: CfnCloudGuardQsModulePropsParametersAllocatePublicAddress | undefined): Record<string, any> | undefined;
/**
 * IAM role to attach to the instance profile of the Management Server.
 *
 * Default: Create with read permissions. Allowed values: None (configure later), Use existing (specify an existing IAM role name), Create with assume role permissions (specify an STS role ARN), Create with read permissions, Create with read-write permissions
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementPermissions
 */
export interface CfnCloudGuardQsModulePropsParametersManagementPermissions {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPermissions#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPermissions#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementPermissions' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementPermissions(obj: CfnCloudGuardQsModulePropsParametersManagementPermissions | undefined): Record<string, any> | undefined;
/**
 * Select 'Over the internet' if any of the gateways you wish to manage are not directly accessed via their private IP address.
 *
 * Default: 'Locally managed'. Allowed values: Locally managed, Over the internet
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewayManagement
 */
export interface CfnCloudGuardQsModulePropsParametersGatewayManagement {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayManagement#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewayManagement#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewayManagement' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewayManagement(obj: CfnCloudGuardQsModulePropsParametersGatewayManagement | undefined): Record<string, any> | undefined;
/**
 * Mandatory only if deploying a secondary Management Server, the Secure Internal Communication key creates trusted connections between Check Point components.
 *
 * Choose a random string consisting of at least 8 alphanumeric characters
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementSicKey
 */
export interface CfnCloudGuardQsModulePropsParametersManagementSicKey {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementSicKey#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementSicKey#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementSicKey' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementSicKey(obj: CfnCloudGuardQsModulePropsParametersManagementSicKey | undefined): Record<string, any> | undefined;
/**
 * A predefined IAM role to attach to the instance profile.
 *
 * Ignored if IAM role is not set to 'Use existing'
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementPredefinedRole
 */
export interface CfnCloudGuardQsModulePropsParametersManagementPredefinedRole {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPredefinedRole#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementPredefinedRole#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementPredefinedRole' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementPredefinedRole(obj: CfnCloudGuardQsModulePropsParametersManagementPredefinedRole | undefined): Record<string, any> | undefined;
/**
 * (optional).
 *
 * Default: 169.254.169.123
 *
 * @schema CfnCloudGuardQsModulePropsParametersNtpPrimary
 */
export interface CfnCloudGuardQsModulePropsParametersNtpPrimary {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNtpPrimary#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNtpPrimary#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersNtpPrimary' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersNtpPrimary(obj: CfnCloudGuardQsModulePropsParametersNtpPrimary | undefined): Record<string, any> | undefined;
/**
 * (optional).
 *
 * Default: 0.pool.ntp.org
 *
 * @schema CfnCloudGuardQsModulePropsParametersNtpSecondary
 */
export interface CfnCloudGuardQsModulePropsParametersNtpSecondary {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNtpSecondary#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersNtpSecondary#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersNtpSecondary' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersNtpSecondary(obj: CfnCloudGuardQsModulePropsParametersNtpSecondary | undefined): Record<string, any> | undefined;
/**
 * (optional).
 *
 * Default: mgmt-aws
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementHostname
 */
export interface CfnCloudGuardQsModulePropsParametersManagementHostname {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementHostname#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementHostname#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementHostname' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementHostname(obj: CfnCloudGuardQsModulePropsParametersManagementHostname | undefined): Record<string, any> | undefined;
/**
 * Determines if this is the primary Management Server or not.
 *
 * Default: true
 *
 * @schema CfnCloudGuardQsModulePropsParametersPrimaryManagement
 */
export interface CfnCloudGuardQsModulePropsParametersPrimaryManagement {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrimaryManagement#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPrimaryManagement#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPrimaryManagement' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPrimaryManagement(obj: CfnCloudGuardQsModulePropsParametersPrimaryManagement | undefined): Record<string, any> | undefined;
/**
 * EBS Volume size of the management server.
 *
 * @schema CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize
 */
export interface CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize(obj: CfnCloudGuardQsModulePropsParametersManagementStackVolumeSize | undefined): Record<string, any> | undefined;
/**
 * Change the admin shell to enable advanced command line configuration.
 *
 * Default: /etc/cli.sh. Allowed values: /etc/cli.sh, /bin/bash, /bin/csh, /bin/tcsh
 *
 * @schema CfnCloudGuardQsModulePropsParametersShellManagementStack
 */
export interface CfnCloudGuardQsModulePropsParametersShellManagementStack {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersShellManagementStack#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersShellManagementStack#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersShellManagementStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersShellManagementStack(obj: CfnCloudGuardQsModulePropsParametersShellManagementStack | undefined): Record<string, any> | undefined;
/**
 * The Elasitc Load Balancer Type.
 *
 * Default: none. Allowed values: none, internal, internet-facing
 *
 * @schema CfnCloudGuardQsModulePropsParametersElbType
 */
export interface CfnCloudGuardQsModulePropsParametersElbType {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbType#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbType#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersElbType' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersElbType(obj: CfnCloudGuardQsModulePropsParametersElbType | undefined): Record<string, any> | undefined;
/**
 * A list of Target Groups to associate with the Auto Scaling group (comma separated list of ARNs, without spaces) (optional).
 *
 * @schema CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups
 */
export interface CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups(obj: CfnCloudGuardQsModulePropsParametersGatewaysTargetGroups | undefined): Record<string, any> | undefined;
/**
 * Determines if the gateways are provisioned using their private or public address.
 *
 * Default: private. Allowed values: private, public
 *
 * @schema CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress
 */
export interface CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress(obj: CfnCloudGuardQsModulePropsParametersControlGatewayOverPrivateOrPublicAddress | undefined): Record<string, any> | undefined;
/**
 * EBS Volume size of the security gateway server.
 *
 * @schema CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize
 */
export interface CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize(obj: CfnCloudGuardQsModulePropsParametersSecurityGatewayVolumeSize | undefined): Record<string, any> | undefined;
/**
 * Allow clients only from this network to communicate with the Web Servers.
 *
 * Default: 0.0.0.0/0
 *
 * @schema CfnCloudGuardQsModulePropsParametersElbClients
 */
export interface CfnCloudGuardQsModulePropsParametersElbClients {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbClients#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersElbClients#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersElbClients' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersElbClients(obj: CfnCloudGuardQsModulePropsParametersElbClients | undefined): Record<string, any> | undefined;
/**
 * Change the admin shell to enable advanced command line configuration.
 *
 * Default: /etc/cli.sh. Allowed Values: /etc/cli.sh /bin/bash /bin/csh /bin/tcsh
 *
 * @schema CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack
 */
export interface CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack(obj: CfnCloudGuardQsModulePropsParametersShellSecurityGatewayStack | undefined): Record<string, any> | undefined;
/**
 * IAM Permissions for the management server.
 *
 * Default: Create with read permissions. Allowed values: Create with read permissions Create with read-write permissions Create with assume role permissions (specify an STS role ARN)
 *
 * @schema CfnCloudGuardQsModulePropsParametersPermissions
 */
export interface CfnCloudGuardQsModulePropsParametersPermissions {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPermissions#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersPermissions#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersPermissions' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersPermissions(obj: CfnCloudGuardQsModulePropsParametersPermissions | undefined): Record<string, any> | undefined;
/**
 * The IAM role will be able to assume these STS Roles (comma separated list of ARNs, without spaces).
 *
 * @schema CfnCloudGuardQsModulePropsParametersStsRoles
 */
export interface CfnCloudGuardQsModulePropsParametersStsRoles {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersStsRoles#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersStsRoles#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersStsRoles' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersStsRoles(obj: CfnCloudGuardQsModulePropsParametersStsRoles | undefined): Record<string, any> | undefined;
/**
 * A 12 digits number that represents the ID of a trusted account.
 *
 * IAM users in this account will be able assume the IAM role and receive the permissions attached to it.
 *
 * @schema CfnCloudGuardQsModulePropsParametersTrustedAccount
 */
export interface CfnCloudGuardQsModulePropsParametersTrustedAccount {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTrustedAccount#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersTrustedAccount#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersTrustedAccount' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersTrustedAccount(obj: CfnCloudGuardQsModulePropsParametersTrustedAccount | undefined): Record<string, any> | undefined;
/**
 * An optional list of Target Groups to associate with the Auto Scaling group (comma separated list of ARNs, without spaces).
 *
 * @schema CfnCloudGuardQsModulePropsParametersServersTargetGroups
 */
export interface CfnCloudGuardQsModulePropsParametersServersTargetGroups {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersTargetGroups#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersTargetGroups#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServersTargetGroups' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServersTargetGroups(obj: CfnCloudGuardQsModulePropsParametersServersTargetGroups | undefined): Record<string, any> | undefined;
/**
 * The ID of Security Group from which access will be allowed to the instances in this Auto Scaling group.
 *
 * @schema CfnCloudGuardQsModulePropsParametersSourceSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsParametersSourceSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersSourceSecurityGroup#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersSourceSecurityGroup#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersSourceSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersSourceSecurityGroup(obj: CfnCloudGuardQsModulePropsParametersSourceSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * The minimal number of servers in the Auto Scaling group.
 *
 * Default: 2
 *
 * @schema CfnCloudGuardQsModulePropsParametersServersMinSize
 */
export interface CfnCloudGuardQsModulePropsParametersServersMinSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersMinSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersMinSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServersMinSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServersMinSize(obj: CfnCloudGuardQsModulePropsParametersServersMinSize | undefined): Record<string, any> | undefined;
/**
 * The maximal number of servers in the Auto Scaling group.
 *
 * Default: 10
 *
 * @schema CfnCloudGuardQsModulePropsParametersServersMaxSize
 */
export interface CfnCloudGuardQsModulePropsParametersServersMaxSize {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersMaxSize#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServersMaxSize#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServersMaxSize' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServersMaxSize(obj: CfnCloudGuardQsModulePropsParametersServersMaxSize | undefined): Record<string, any> | undefined;
/**
 * The servers name tag.
 *
 * Default: Server
 *
 * @schema CfnCloudGuardQsModulePropsParametersServerName
 */
export interface CfnCloudGuardQsModulePropsParametersServerName {
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerName#Type
     */
    readonly type: string;
    /**
     * @schema CfnCloudGuardQsModulePropsParametersServerName#Description
     */
    readonly description: string;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsParametersServerName' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsParametersServerName(obj: CfnCloudGuardQsModulePropsParametersServerName | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesVpc
 */
export interface CfnCloudGuardQsModulePropsResourcesVpc {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesVpc#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesVpc#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesVpc' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesVpc(obj: CfnCloudGuardQsModulePropsResourcesVpc | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInternetGateway
 */
export interface CfnCloudGuardQsModulePropsResourcesInternetGateway {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternetGateway#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternetGateway#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInternetGateway' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInternetGateway(obj: CfnCloudGuardQsModulePropsResourcesInternetGateway | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment
 */
export interface CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment(obj: CfnCloudGuardQsModulePropsResourcesVpcGatewayAttachment | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet1 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet1' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet1(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet1 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet2 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet2' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet2(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet2 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet3 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet3' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet3(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet3 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet4 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet4' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet4(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet4 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnetRouteTable | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnetRoute | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet1RouteTableAssociation | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet2RouteTableAssociation | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet3RouteTableAssociation | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation(obj: CfnCloudGuardQsModulePropsResourcesPublicSubnet4RouteTableAssociation | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet1
 */
export interface CfnCloudGuardQsModulePropsResourcesPrivateSubnet1 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet1#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet1#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPrivateSubnet1' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPrivateSubnet1(obj: CfnCloudGuardQsModulePropsResourcesPrivateSubnet1 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet2
 */
export interface CfnCloudGuardQsModulePropsResourcesPrivateSubnet2 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet2#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet2#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPrivateSubnet2' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPrivateSubnet2(obj: CfnCloudGuardQsModulePropsResourcesPrivateSubnet2 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet3
 */
export interface CfnCloudGuardQsModulePropsResourcesPrivateSubnet3 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet3#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet3#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPrivateSubnet3' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPrivateSubnet3(obj: CfnCloudGuardQsModulePropsResourcesPrivateSubnet3 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet4
 */
export interface CfnCloudGuardQsModulePropsResourcesPrivateSubnet4 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet4#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPrivateSubnet4#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPrivateSubnet4' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPrivateSubnet4(obj: CfnCloudGuardQsModulePropsResourcesPrivateSubnet4 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet1
 */
export interface CfnCloudGuardQsModulePropsResourcesTgwSubnet1 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet1#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet1#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesTgwSubnet1' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesTgwSubnet1(obj: CfnCloudGuardQsModulePropsResourcesTgwSubnet1 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet2
 */
export interface CfnCloudGuardQsModulePropsResourcesTgwSubnet2 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet2#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet2#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesTgwSubnet2' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesTgwSubnet2(obj: CfnCloudGuardQsModulePropsResourcesTgwSubnet2 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet3
 */
export interface CfnCloudGuardQsModulePropsResourcesTgwSubnet3 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet3#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet3#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesTgwSubnet3' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesTgwSubnet3(obj: CfnCloudGuardQsModulePropsResourcesTgwSubnet3 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet4
 */
export interface CfnCloudGuardQsModulePropsResourcesTgwSubnet4 {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet4#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesTgwSubnet4#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesTgwSubnet4' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesTgwSubnet4(obj: CfnCloudGuardQsModulePropsResourcesTgwSubnet4 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesExternalAlbSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer
 */
export interface CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer(obj: CfnCloudGuardQsModulePropsResourcesExternalLoadBalancer | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup(obj: CfnCloudGuardQsModulePropsResourcesExternalLbTargetGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesExternalLbListener
 */
export interface CfnCloudGuardQsModulePropsResourcesExternalLbListener {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLbListener#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesExternalLbListener#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesExternalLbListener' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesExternalLbListener(obj: CfnCloudGuardQsModulePropsResourcesExternalLbListener | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesChkpGatewayRole
 */
export interface CfnCloudGuardQsModulePropsResourcesChkpGatewayRole {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesChkpGatewayRole#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesChkpGatewayRole#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesChkpGatewayRole' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesChkpGatewayRole(obj: CfnCloudGuardQsModulePropsResourcesChkpGatewayRole | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack
 */
export interface CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack(obj: CfnCloudGuardQsModulePropsResourcesInstanceProfileSecurityGatewayStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack
 */
export interface CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack(obj: CfnCloudGuardQsModulePropsResourcesNotificationTopicSecurityGatewayStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer
 */
export interface CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer(obj: CfnCloudGuardQsModulePropsResourcesElasticLoadBalancer | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesPermissiveSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesGatewayGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesGatewayGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesGatewayGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesGatewayGroup(obj: CfnCloudGuardQsModulePropsResourcesGatewayGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig
 */
export interface CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig(obj: CfnCloudGuardQsModulePropsResourcesGatewayLaunchConfig | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy
 */
export interface CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy(obj: CfnCloudGuardQsModulePropsResourcesGatewayScaleUpPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy
 */
export interface CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy(obj: CfnCloudGuardQsModulePropsResourcesGatewayScaleDownPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack
 */
export interface CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack(obj: CfnCloudGuardQsModulePropsResourcesCpuAlarmHighSecurityGatewayStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack
 */
export interface CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack(obj: CfnCloudGuardQsModulePropsResourcesCpuAlarmLowSecurityGatewayStack | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesElbSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesElbSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesElbSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesElbSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesElbSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesElbSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesElbSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyHandle
 */
export interface CfnCloudGuardQsModulePropsResourcesManagementReadyHandle {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyHandle#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyHandle#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesManagementReadyHandle' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesManagementReadyHandle(obj: CfnCloudGuardQsModulePropsResourcesManagementReadyHandle | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyCondition
 */
export interface CfnCloudGuardQsModulePropsResourcesManagementReadyCondition {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyCondition#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementReadyCondition#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesManagementReadyCondition' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesManagementReadyCondition(obj: CfnCloudGuardQsModulePropsResourcesManagementReadyCondition | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesManagementSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesCmeiamRole
 */
export interface CfnCloudGuardQsModulePropsResourcesCmeiamRole {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCmeiamRole#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCmeiamRole#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesCmeiamRole' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesCmeiamRole(obj: CfnCloudGuardQsModulePropsResourcesCmeiamRole | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfile
 */
export interface CfnCloudGuardQsModulePropsResourcesInstanceProfile {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfile#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInstanceProfile#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInstanceProfile' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInstanceProfile(obj: CfnCloudGuardQsModulePropsResourcesInstanceProfile | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesManagementInstance
 */
export interface CfnCloudGuardQsModulePropsResourcesManagementInstance {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementInstance#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesManagementInstance#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesManagementInstance' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesManagementInstance(obj: CfnCloudGuardQsModulePropsResourcesManagementInstance | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesPublicAddress
 */
export interface CfnCloudGuardQsModulePropsResourcesPublicAddress {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicAddress#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesPublicAddress#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesPublicAddress' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesPublicAddress(obj: CfnCloudGuardQsModulePropsResourcesPublicAddress | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesAddressAssoc
 */
export interface CfnCloudGuardQsModulePropsResourcesAddressAssoc {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesAddressAssoc#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesAddressAssoc#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesAddressAssoc' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesAddressAssoc(obj: CfnCloudGuardQsModulePropsResourcesAddressAssoc | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesInternalSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup(obj: CfnCloudGuardQsModulePropsResourcesInternalLbTargetGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer
 */
export interface CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer(obj: CfnCloudGuardQsModulePropsResourcesInternalLoadBalancer | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesInternalLbListener
 */
export interface CfnCloudGuardQsModulePropsResourcesInternalLbListener {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLbListener#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesInternalLbListener#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesInternalLbListener' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesInternalLbListener(obj: CfnCloudGuardQsModulePropsResourcesInternalLbListener | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopic
 */
export interface CfnCloudGuardQsModulePropsResourcesNotificationTopic {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopic#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesNotificationTopic#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesNotificationTopic' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesNotificationTopic(obj: CfnCloudGuardQsModulePropsResourcesNotificationTopic | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesServersSecurityGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesServersSecurityGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersSecurityGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersSecurityGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesServersSecurityGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesServersSecurityGroup(obj: CfnCloudGuardQsModulePropsResourcesServersSecurityGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration
 */
export interface CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration(obj: CfnCloudGuardQsModulePropsResourcesServersLaunchConfiguration | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesServersGroup
 */
export interface CfnCloudGuardQsModulePropsResourcesServersGroup {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersGroup#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesServersGroup#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesServersGroup' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesServersGroup(obj: CfnCloudGuardQsModulePropsResourcesServersGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesScaleUpPolicy
 */
export interface CfnCloudGuardQsModulePropsResourcesScaleUpPolicy {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesScaleUpPolicy#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesScaleUpPolicy#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesScaleUpPolicy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesScaleUpPolicy(obj: CfnCloudGuardQsModulePropsResourcesScaleUpPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesScaleDownPolicy
 */
export interface CfnCloudGuardQsModulePropsResourcesScaleDownPolicy {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesScaleDownPolicy#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesScaleDownPolicy#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesScaleDownPolicy' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesScaleDownPolicy(obj: CfnCloudGuardQsModulePropsResourcesScaleDownPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh
 */
export interface CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh(obj: CfnCloudGuardQsModulePropsResourcesCpuAlarmHigh | undefined): Record<string, any> | undefined;
/**
 * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLow
 */
export interface CfnCloudGuardQsModulePropsResourcesCpuAlarmLow {
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLow#Type
     */
    readonly type?: string;
    /**
     * @schema CfnCloudGuardQsModulePropsResourcesCpuAlarmLow#Properties
     */
    readonly properties?: any;
}
/**
 * Converts an object of type 'CfnCloudGuardQsModulePropsResourcesCpuAlarmLow' to JSON representation.
 */
export declare function toJson_CfnCloudGuardQsModulePropsResourcesCpuAlarmLow(obj: CfnCloudGuardQsModulePropsResourcesCpuAlarmLow | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `AWSQS::CheckPoint::CloudGuardQS::MODULE`.
 *
 * @external
 * @cloudformationResource AWSQS::CheckPoint::CloudGuardQS::MODULE
 * @link http://unknown-url
 */
export declare class CfnCloudGuardQsModule extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "AWSQS::CheckPoint::CloudGuardQS::MODULE";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnCloudGuardQsModuleProps;
    /**
     * Create a new `AWSQS::CheckPoint::CloudGuardQS::MODULE`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnCloudGuardQsModuleProps);
}
